@@ -23,8 +23,6 @@ from neutron_lib import exceptions as nexception
 from neutron_lib.plugins import constants as nconstants
 from neutron_lib.services import base as service_base
 
-import six
-
 from neutron.api.v2 import resource_helper
 
 from neutron_vpnaas._i18n import _
@@ -207,25 +205,30 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
-               'primary_key': True},
+               'primary_key': True,
+               'is_sort_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
                       'validate': {
                           'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
-                      'is_visible': True},
+                      'is_visible': True,
+                      'is_sort_key': True},
         'name': {'allow_post': True, 'allow_put': True,
                  'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                 'is_visible': True, 'default': ''},
+                 'is_visible': True, 'default': '',
+                 'is_sort_key': True},
         'description': {'allow_post': True, 'allow_put': True,
                         'validate': {
                             'type:string': db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
         'subnet_id': {'allow_post': True, 'allow_put': False,
                       'validate': {'type:uuid_or_none': None},
-                      'is_visible': True, 'default': None},
+                      'is_visible': True, 'default': None,
+                      'is_sort_key': True},
         'router_id': {'allow_post': True, 'allow_put': False,
                       'validate': {'type:uuid': None},
-                      'is_visible': True},
+                      'is_visible': True,
+                      'is_sort_key': True},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
                            'convert_to': converters.convert_to_boolean,
@@ -242,15 +245,18 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
-               'primary_key': True},
+               'primary_key': True,
+               'is_sort_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
                       'validate': {
                           'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
-                      'is_visible': True},
+                      'is_visible': True,
+                      'is_sort_key': True},
         'name': {'allow_post': True, 'allow_put': True,
                  'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                 'is_visible': True, 'default': ''},
+                 'is_visible': True, 'default': '',
+                 'is_sort_key': True},
         'description': {'allow_post': True, 'allow_put': True,
                         'validate': {
                             'type:string': db_const.DESCRIPTION_FIELD_SIZE},
@@ -330,15 +336,18 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
-               'primary_key': True},
+               'primary_key': True,
+               'is_sort_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
                       'validate': {
                           'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
-                      'is_visible': True},
+                      'is_visible': True,
+                      'is_sort_key': True},
         'name': {'allow_post': True, 'allow_put': True,
                  'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                 'is_visible': True, 'default': ''},
+                 'is_visible': True, 'default': '',
+                 'is_sort_key': True},
         'description': {'allow_post': True, 'allow_put': True,
                         'validate': {
                             'type:string': db_const.DESCRIPTION_FIELD_SIZE},
@@ -396,15 +405,18 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
-               'primary_key': True},
+               'primary_key': True,
+               'is_sort_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
                       'validate': {
                           'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
-                      'is_visible': True},
+                      'is_visible': True,
+                      'is_sort_key': True},
         'name': {'allow_post': True, 'allow_put': True,
                  'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                 'is_visible': True, 'default': ''},
+                 'is_visible': True, 'default': '',
+                 'is_sort_key': True},
         'description': {'allow_post': True, 'allow_put': True,
                         'validate': {
                             'type:string': db_const.DESCRIPTION_FIELD_SIZE},
@@ -500,8 +512,7 @@ class Vpnaas(extensions.ExtensionDescriptor):
         return {}
 
 
-@six.add_metaclass(abc.ABCMeta)
-class VPNPluginBase(service_base.ServicePluginBase):
+class VPNPluginBase(service_base.ServicePluginBase, metaclass=abc.ABCMeta):
 
     def get_plugin_type(self):
         return nconstants.VPN
