@@ -14,8 +14,8 @@
 #    under the License.
 
 import copy
+from unittest import mock
 
-import mock
 from neutron.tests.unit.api.v2 import test_base as test_api_v2
 from neutron_lib.plugins import constants as nconstants
 from oslo_utils import uuidutils
@@ -37,10 +37,9 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
                            'ikepolicy': 'ikepolicies',
                            'ipsec_site_connection': 'ipsec-site-connections',
                            'endpoint_group': 'endpoint-groups'}
-        self._setUpExtension(
+        self.setup_extension(
             'neutron_vpnaas.extensions.vpnaas.VPNPluginBase', nconstants.VPN,
-            vpnaas.RESOURCE_ATTRIBUTE_MAP, vpnaas.Vpnaas,
-            'vpn', plural_mappings=plural_mappings,
+            vpnaas.Vpnaas, 'vpn', plural_mappings=plural_mappings,
             use_quota=True)
 
     def test_ikepolicy_create(self):
